@@ -1,10 +1,8 @@
-from .price import price
-from .trade import trade
 from .API import API
-
+from .APIadmin import APIadmin
 
 __title__ = "SIGMATMPY"
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 __author__ = "SIGMATM"
 __license__ = "MIT"
 __copyright__ = "Copyright (c) 2021 BFJFunds"
